==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/General/lyrics/translations/lyrics_plugin_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>Zobraziť text skladby</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Plugin textov skladieb</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>O plugine textov skladieb</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp plugin textov skladieb</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Tento plugin sťahuje texty z LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Plugin textov skladieb</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="45"/>
        <source>Artist:</source>
        <translation>Interprét:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="55"/>
        <source>Title:</source>
        <translation>Názov:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="65"/>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="36"/>
        <source>No connection</source>
        <translation>Žiadne pripojenie</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="76"/>
        <location filename="../lyricswindow.cpp" line="209"/>
        <source>Done</source>
        <translation>Dokončené</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="79"/>
        <location filename="../lyricswindow.cpp" line="103"/>
        <location filename="../lyricswindow.cpp" line="109"/>
        <location filename="../lyricswindow.cpp" line="117"/>
        <location filename="../lyricswindow.cpp" line="125"/>
        <location filename="../lyricswindow.cpp" line="136"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="130"/>
        <location filename="../lyricswindow.cpp" line="165"/>
        <source>Not found</source>
        <translation>Nenájdené</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="151"/>
        <location filename="../lyricswindow.cpp" line="178"/>
        <source>Receiving</source>
        <translation>Sťahujem</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="179"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Text: %1 - %2</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.3.orig.tar.bz2: qmmp-1.4.3/src/plugins/General/lyrics/translations/lyrics_plugin_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>Zobraziť text skladby</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Plugin textov skladieb</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="49"/>
        <source>About Lyrics Plugin</source>
        <translation>O plugine textov skladieb</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp plugin textov skladieb</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Tento plugin sťahuje texty z LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Based on Ultimate Lyrics script by Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Plugin textov skladieb</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Provider:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="122"/>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="139"/>
        <source>Track:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="146"/>
        <source>Artist:</source>
        <translation>Interprét:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="161"/>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="115"/>
        <source>Title:</source>
        <translation>Názov:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="115"/>
        <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="126"/>
        <source>Not found</source>
        <translation>Nenájdené</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="136"/>
        <source>Error: %1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="149"/>
        <source>Receiving</source>
        <translation>Sťahujem</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="204"/>
        <source>cache</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Lyrics Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Lyrics providers:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UltimateLyricsParser</name>
    <message>
        <location filename="../ultimatelyricsparser.cpp" line="119"/>
        <source>%1 (line: %2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
